@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: download_ui.c,v 1.11.2.1 2004/05/01 04:34:27 fuyu Exp $
+ * $Id: download_ui.c,v 1.11.2.2 2004/05/15 15:39:48 fuyu Exp $
  */
 
 #include "config.h"
@@ -106,7 +106,7 @@ access_progressed_cb(OchushaAsyncBuffer *buffer,
       else
 	{
 	  char message[256];
-	  int percent = bytes_read * 100 / bytes_total;
+	  int percent = (bytes_read / bytes_total) * 100;
 	  snprintf(message, 256, "%d%% (%d/%d)",
 		   percent, bytes_read, bytes_total);
 	  gtk_progress_bar_set_text(pbar, message);
