@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: image_ui.c,v 1.5.2.11 2004/05/04 08:16:01 fuyu Exp $
+ * $Id: image_ui.c,v 1.5.2.12 2004/05/15 17:28:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,6 +52,9 @@
 #include <sys/stat.h>
 #include <utime.h>
 
+/* #undef DEBUG_CACHE		0 */
+/* #undef DEBUG_CACHE_MOST 	0 */
+
 
 /*
  * åϢ
@@ -621,25 +624,7 @@ download_image(WorkerThread *employee, gpointer args)
       OchushaApplication *application
 	= g_object_get_data(G_OBJECT(buffer), "application");
       if (application != NULL)
-	{
-#if 1
-	  cache_image(application, image_info->url, buffer);
-#else
-	  int fd = ochusha_config_image_cache_open_file(&application->config,
-						image_info->url,
-						O_WRONLY | O_TRUNC | O_CREAT);
-	  if (fd >= 0)
-	    {
-	      ssize_t len = write(fd, (void *)buffer->buffer, buffer->length);
-	      close(fd);
-	      if (len != buffer->length)
-		{
-		  ochusha_config_image_cache_unlink_file(&application->config,
-							 image_info->url);
-		}
-	    }
-#endif
-	}
+	cache_image(application, image_info->url, buffer);
     }
 
   OCHU_OBJECT_UNREF(buffer);
@@ -759,6 +744,8 @@ ochusha_download_image(OchushaApplication *application, const char *url,
 					OCHUSHA_NETWORK_BROKER_CACHE_ONLY,
 					TRUE,
 					application->image_chunksize);
+      if (buffer != NULL)
+	touch_cache(application, url);
     }
 
   if (buffer == NULL)
@@ -857,9 +844,6 @@ cache_entry_compare(gconstpointer a, gconstpointer b)
 }
 
 
-/* #undef DEBUG_CACHE		0 */
-/* #undef DEBUG_CACHE_MOST 	0 */
-
 #ifdef DEBUG_CACHE_MOST
 static void
 dump_cache_entry(CacheEntry *entry, gpointer unused)
@@ -919,6 +903,9 @@ cache_image(OchushaApplication *application, const char *url,
 				O_WRONLY | O_TRUNC | O_CREAT);
   if (fd < 0)
     {
+#ifdef DEBUG_CACHE
+      fprintf(stderr, "Couldn't open image cache file: %s\n", url);
+#endif
       G_FREE(filename);
       return;	/* äꤢ롣*/
     }
@@ -930,6 +917,9 @@ cache_image(OchushaApplication *application, const char *url,
       ochusha_config_unlink_file(&application->config,
 				 filename, "image_cache");
       G_FREE(filename);
+#ifdef DEBUG_CACHE
+      fprintf(stderr, "Writing failed for image cache file: %s\n", url);
+#endif
       return;	/* äꤢ롣*/
     }
   close(fd);
