@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.28.2.1 2004/05/01 04:34:27 fuyu Exp $
+ * $Id: main.c,v 1.28.2.3 2004/05/24 10:49:23 fuyu Exp $
  */
 
 #include "config.h"
@@ -60,6 +60,32 @@
 #define MAXIMUM_NUM_MODEST_THREADS	4
 
 
+#if GTK_MINOR_VERSION > 2
+static int lock_depth = 0;
+static GStaticRecMutex ochusha_gdk_threads_lock = G_STATIC_REC_MUTEX_INIT;
+
+
+static void
+ochusha_gdk_threads_enter(void)
+{
+  g_static_rec_mutex_lock(&ochusha_gdk_threads_lock);
+  lock_depth++;
+#if 0
+  if (lock_depth > 1)
+    fprintf(stderr, "gdk_threads_enter(): depth=%d\n", lock_depth);
+#endif
+}
+
+
+static void
+ochusha_gdk_threads_leave(void)
+{
+  lock_depth--;
+  g_static_rec_mutex_unlock(&ochusha_gdk_threads_lock);
+}
+#endif
+
+
 #if DEBUG_GDK_LOCK
 pthread_t volatile last_lock_owner = NULL;
 volatile const char *last_file;
@@ -219,6 +245,10 @@ main(int argc, char *argv[])
   gtk_rc_add_default_file(PKGDATADIR "/" OCHUSHA_GTKRC);
 
   g_thread_init(NULL);
+#if GTK_MINOR_VERSION > 2
+  gdk_threads_set_lock_functions(ochusha_gdk_threads_enter,
+				 ochusha_gdk_threads_leave);
+#endif
   gdk_threads_init();
   gtk_set_locale();
   gtk_init(&real_argc, &real_argv);
