@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.74 2004/02/28 23:45:13 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.76.2.2 2004/05/04 07:22:10 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -45,7 +45,6 @@
 
 
 #define ENABLE_DEBUG_CONSOLE						1
-#define ENABLE_MAIN_TOOLBAR						0
 
 #define OCHUSHA_GTKRC					"ochusha-gtkrc"
 #define OCHUSHA_PREFS_GTKRC				"ochusha-prefs-gtkrc"
@@ -53,8 +52,9 @@
 #define OCHUSHA_SESSION_XML				"session.xml.gz"
 #define OCHUSHA_INIT_SCM				"ochusha-init.scm"
 #define OCHUSHA_A_BONE_IMAGE_TXT			"a-bone-image.txt"
+#define OCHUSHA_A_BONE_SERVER_TXT			"a-bone-server.txt"
 
-#define OCHUSHA_CURRENT_CONFIG_VERSION					2
+#define OCHUSHA_CURRENT_CONFIG_VERSION					3
 
 #define OCHUSHA_DEFAULT_WIDTH						600
 #define OCHUSHA_DEFAULT_HEIGHT						400
@@ -95,6 +95,10 @@
 #define OCHUSHA_DEFAULT_POPUP_IMAGE_WIDTH				480
 #define OCHUSHA_DEFAULT_POPUP_IMAGE_HEIGHT				360
 
+#define OCHUSHA_DEFAULT_CAPACITY_OF_IMAGE_CACHE		32
+#define OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_CACHE_FILES	256
+
+
 #define THREAD_VIEW_EXTRA_WIDTH			30
 
 #define OCHUSHA_MINIMIZED_ICON			"Ochusha-Minimized"
@@ -145,20 +149,17 @@ struct _OchushaApplication
 
   GtkWidget *menu_bar;
 
-#if ENABLE_MAIN_TOOLBAR
-  GtkToolbar *toolbar;
-
-  /* toolbar */
-  GtkCombo *url_box;
-#endif
-
   GtkWidget *contents_window;		/* PanedNotebook */
 
   /* contents_windowselectorʬ */
   GtkWidget *boardlist_view;		/* BoardlistView */
 
   /* ߤĤΥ˥ե륿ŬѤ뤫ɤɽ */
+#if GTK_MINOR_VERSION <= 2
   GtkToggleButton *filter_button;
+#else
+  GtkToggleToolButton *filter_button;
+#endif
 
   GtkStatusbar *statusbar;
 
@@ -270,11 +271,15 @@ struct _OchushaApplication
   gboolean analyze_informal_links;
 
 
+  /* Ϣ */
   int inline_image_width;
   int inline_image_height;
   int popup_image_width;
   int popup_image_height;
 
+  off_t capacity_of_image_cache;
+  int maximum_number_of_cache_files;
+
 
   /* ֥֥饦Υޥɥ饤ƥץ졼 */
   char *web_browser_template;
@@ -332,45 +337,14 @@ struct _OchushaApplication
 };
 
 
-typedef enum
-{
-  MAIN_MENU_QUIT = 1,
-  MAIN_MENU_OPEN_URL,
-  MAIN_MENU_REFRESH_BOARDLIST,
-  MAIN_MENU_CREATE_NEW_CATEGORY,
-  MAIN_MENU_ADD_BOARD,
-  MAIN_MENU_CREATE_NEW_VIRTUAL_BOARD,
-  MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS,
-  MAIN_MENU_REFRESH_THREAD,
-  MAIN_MENU_REFRESH_THREAD_ALL,
-  MAIN_MENU_REFRESH_THREADLIST,
-  MAIN_MENU_REFRESH_THREADLIST_ALL,
-  MAIN_MENU_USE_BUILTIN_CALCULATE_WEIGHT,
-  MAIN_MENU_SORT_THREADLIST_BY_WEIGHT,
-  MAIN_MENU_HIDE_HIDDEN_THREADS,
-  MAIN_MENU_DEBUG_CONSOLE,
-  MAIN_MENU_OPTIONS,
-  MAIN_MENU_SELECT_BOARDLIST_THREADLIST_FONTS,
-  MAIN_MENU_SELECT_THREAD_FONTS,
-  MAIN_MENU_ABOUT,
-} OchushaMainMenuAction;
-
-
 void ochusha_write_preferences(OchushaApplication *application);
 void ochusha_init_application(OchushaApplication *application);
-void ochusha_set_main_menu_sensitive(OchushaMainMenuAction action,
-				     gboolean sensitive);
 
 void ochusha_clipboard_set_text(OchushaApplication *application,
 				const gchar *text);
 
 void ochusha_open_url(OchushaApplication *application, const char *url,
 		      gboolean in_tab, gboolean use_web_browser);
-#if ENABLE_MAIN_TOOLBAR
-void set_current_url(OchushaApplication *application, const char *url);
-const char *get_current_url(OchushaApplication *application);
-#endif
-
 void setup_for_tab_label_animation(OchushaAsyncBuffer *buffer,
 				   IconLabel *tab_label);
 GtkWidget *get_tab_label(const gchar *label_text);
