@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.17.2.2 2004/05/15 16:32:11 fuyu Exp $
+ * $Id: ochusha.h,v 1.17.2.3 2004/05/24 09:58:46 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -54,7 +54,7 @@ extern "C" {
 #define OCHUSHA_SUBJECT_TXT		"subject.txt"
 #define OCHUSHA_SUBBACK_HTML		"subback.html"
 
-#define OCHUSHA_DOLIB_URL		"https://tiger2.he.net/~tora3n2c/futen.cgi"
+#define OCHUSHA_DOLIB_URL		"https://2chv.tora3.net/futen.cgi"
 #define OCHUSHA_DOLIB_USER_AGENT	"DOLIB/1.00"
 #define OCHUSHA_DOLIB_X_2CH_UA		"Ochusha/" VERSION
 #define OCHUSHA_CA_BUNDLE_CRT		PKGDATADIR "/ca-bundle.crt"
