@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.30.2.2 2004/05/15 16:32:11 fuyu Exp $
+ * $Id: utils.c,v 1.30.2.3 2004/05/24 10:03:40 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION	1
@@ -255,6 +255,47 @@ wipe_string(const gchar *string)
 }
 
 
+/*
+ * ochusha_utils_shell_escape_text
+ *
+ * Ϳ줿ʸ򥷥Ϥޥɥ饤Ȥƥפɬ
+ * ʸ򥨥פʸΥԡ֤
+ * Ǥϡ#\#֤
+ */
+char *
+ochusha_utils_shell_escape_text(const char *text)
+{
+  int count = 0;
+  const char *cur_pos = text;
+  char *result;
+  char *tmp_pos;
+
+  while (*cur_pos != '\0')
+    {
+      if (*cur_pos == '#')
+	count++;
+      cur_pos++;
+    }
+
+  if (count == 0)
+    return G_STRDUP(text);
+
+  result = G_MALLOC(strlen(text) + count);
+  cur_pos = text;
+  tmp_pos = result;
+  do
+    {
+      *tmp_pos++ = *cur_pos;
+      if (*cur_pos == '#')
+	{
+	  tmp_pos[-1] = '\\';
+	  *tmp_pos++ = '#';
+	}
+    } while (*cur_pos++ != '\0');
+  return result;
+}
+
+
 /*
  * ochusha_utils_url_extract_scheme
  *
