@@ -27,6 +27,7 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
@@ -352,6 +353,15 @@ http_trans_connect(http_trans_conn *a_conn)
 
 	  if (verify_result != X509_V_OK)
 	    {
+#if 0
+	      char *version = SSL_get_cipher_version(a_conn->ssl);
+	      X509 *server_cert = SSL_get_peer_certificate(a_conn->ssl);
+	      fprintf(stderr, "SSL Protocol: %s\n", version);
+	      fprintf(stderr, "Server certificate\n");
+	      fprintf(stderr, "  subject: %s\n", X509_NAME_oneline(X509_get_subject_name(server_cert), 0, 0));
+	      fprintf(stderr, "  issuer: %s\n", X509_NAME_oneline(X509_get_issuer_name(server_cert), 0, 0));
+	      X509_free(server_cert);
+#endif
 	      http_trans_close_ssl(a_conn);
 	      a_conn->error_type = http_trans_err_type_ssl_verification;
 	      a_conn->error = -1;
@@ -420,6 +430,81 @@ http_trans_get_host_error(int a_herror)
     }
 }
 
+
+#ifdef ENABLE_OPENSSL
+const char *
+http_trans_get_ssl_error(int a_herror)
+{
+  switch (a_herror)
+    {
+    case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT:
+      return "Unable to get issuer certificate";
+    case X509_V_ERR_UNABLE_TO_GET_CRL:
+      return "Unable to get certificate CRL";
+    case X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE:
+      return "Unable to decrypt certificate's signature";
+    case X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE:
+      return "Unable to decrypt CRL's signature";
+    case X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY:
+      return "Unable to decode issuer public key";
+    case X509_V_ERR_CERT_SIGNATURE_FAILURE:
+      return "Certificate signature failure";
+    case X509_V_ERR_CERT_NOT_YET_VALID:
+      return "Certificate is not yet valid";
+    case X509_V_ERR_CERT_HAS_EXPIRED:
+      return "Certificate has expired";
+    case X509_V_ERR_CRL_NOT_YET_VALID:
+      return "CRL is not yet valid";
+    case X509_V_ERR_CRL_HAS_EXPIRED:
+      return "CRL has expired";
+    case X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD:
+      return "Format error in certificate's notBefore field";
+    case X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD:
+      return "Format error in certificate's notAfter field";
+    case X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD:
+      return "Format error in CRL's lastUpdate field";
+    case X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD:
+      return "Format error in CRL's nextUpdate field";
+    case X509_V_ERR_OUT_OF_MEM:
+      return "Out of Memory happen during verification";
+    case X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT:
+      return "Self signed certificate";
+    case X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN:
+      return "Self signed certificate in certificate chain";
+    case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY:
+      return "Unable to get local issuer certificate";
+    case X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE:
+      return "Unable to verify the first certificate";
+    case X509_V_ERR_CERT_CHAIN_TOO_LONG:
+      return "Certificate chain too long";
+    case X509_V_ERR_CERT_REVOKED:
+      return "Certificate revoked";
+    case X509_V_ERR_INVALID_CA:
+      return "Invalid CA certificate";
+    case X509_V_ERR_PATH_LENGTH_EXCEEDED:
+      return "Path length constraint exceeded";
+    case X509_V_ERR_INVALID_PURPOSE:
+      return "Unsupported certificate purpose";
+    case X509_V_ERR_CERT_UNTRUSTED:
+      return "Certificate not trusted";
+    case X509_V_ERR_CERT_REJECTED:
+      return "Certificate has rejected";
+    case X509_V_ERR_SUBJECT_ISSUER_MISMATCH:
+      return "Subject issuer mismatch";
+    case X509_V_ERR_AKID_SKID_MISMATCH:
+      return "Authority and subject key identifier mismatch";
+    case X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH:
+      return "Authority and issuer serial number mismatch";
+    case X509_V_ERR_KEYUSAGE_NO_CERTSIGN:
+      return "Key usage does not include certificate signing";
+    case X509_V_ERR_APPLICATION_VERIFICATION:
+      return "Application verification failure";
+    }
+  return "Unknown SSL verification error";
+}
+#endif
+
+
 int
 http_trans_append_data_to_buf(http_trans_conn *a_conn,
 			      const char *a_data,
